
import { useAjax } from '@/Hook/useAjax'
import { CampaignTypeEnum, ConfiguredStatusEnum, PromotedObjectType } from '@/services/launchAdq/enum'
import { Col, Row, Input, Select, Button, message } from 'antd'
import React, { useEffect, useState, useCallback } from 'react'
import TableData from '../../components/TableData'
import tableConfig from './tableConfig'
import { getAdqCampaignList, putAdqCampaignPage } from '@/services/launchAdq/adq'

function Campaign(props: { accountId: string, adAccountId: string, userId: string }) {
    let { accountId, adAccountId, userId } = props
    // api方法
    const listAjax = useAjax((params) => getAdqCampaignList(params), { formatResult: true })
    const syncAjax = useAjax((adAccountId) => putAdqCampaignPage(adAccountId))
    console.log('创意=====》')
    useEffect(() => {
        getList({ pageNum: 1, pageSize: 20 })
    }, [accountId, userId])
    // 获取列表
    const getList = useCallback((params: {
        pageNum: number;
        pageSize: number;
        userId?: string;//用户ID
        accountId?: string;//账号本地ID
        campaignName?: string;//计划名称
        configuredStatus?: string;//计划状态
        campaignType?: string;//计划类型
        promotedObjectType?: string;//推广目标类型
    }) => {
        if (!params.campaignName || params.campaignName !== listAjax?.params[0]?.adcreativeName) {
            !params.campaignName && delete params.campaignName
            listAjax.run({ ...params, userId, accountId })
        }
    }, [accountId, userId, listAjax])
    // 同步 
    const sync = useCallback(() => {
        if (!adAccountId) {
            message.error('请先选择要同步的广点通账号!')
            return
        }
        syncAjax.run(adAccountId).then(res => {
            console.log(res)
            res && listAjax.refresh()
            res ? message.success('同步成功！') : message.error('同步失败！')

        })
    }, [adAccountId, listAjax])
    return <div>
        <TableData
            columns={tableConfig}
            ajax={listAjax}
            syncAjax={sync}
            dataSource={listAjax?.data?.data?.records}
            loading={listAjax?.loading || syncAjax?.loading}
            scroll={{ x: 2000 }}
            total={listAjax?.data?.data?.total}
            page={listAjax?.data?.data?.current}
            pageSize={listAjax?.data?.data?.size}
            myKey={'campaignId'}
            leftChild={<>
                <Row gutter={[10, 10]}>
                    <Col>
                        <Input
                            placeholder='创意名称'
                            allowClear
                            onBlur={(e) => {
                                let value = e.target.value
                                getList({ pageNum: 1, pageSize: 20, campaignName: value })
                            }}
                            onKeyDownCapture={(e: any) => {
                                let key = e.key
                                if (key === 'Enter') {
                                    let value = e.target.value
                                    getList({ pageNum: 1, pageSize: 20, campaignName: value })
                                }
                            }}
                            onChange={(e) => {
                                let value = e.target.value
                                if (!value) {
                                    getList({ pageNum: 1, pageSize: 20, campaignName: value })
                                }
                            }}
                        />
                    </Col>
                    <Col>
                        <Select placeholder='推广目标选择' style={{ minWidth: 200 }} showSearch filterOption={(input: any, option: any) =>
                            (option!.children as unknown as string).toLowerCase().includes(input.toLowerCase())
                        } allowClear onChange={(value: any) => {
                            getList({ pageNum: 1, pageSize: 20, promotedObjectType:value })
                        }}>
                            {
                                Object.keys(PromotedObjectType).map(key => {
                                    // let obj = JSON.parse(PromotedObjectType[key])
                                    return <Select.Option value={key} key={key}>{PromotedObjectType[key]}</Select.Option>
                                })
                            }
                        </Select>
                    </Col>
                    <Col>
                        <Select placeholder='计划状态' style={{ minWidth: 200 }} showSearch filterOption={(input: any, option: any) =>
                            (option!.children as unknown as string).toLowerCase().includes(input.toLowerCase())
                        } allowClear onChange={(value: any) => {
                            getList({ pageNum: 1, pageSize: 20, configuredStatus: value })
                        }}>
                            {
                                Object.keys(ConfiguredStatusEnum).map(key => {
                                    // let obj = JSON.parse(PromotedObjectType[key])
                                    return <Select.Option value={key} key={key}>{ConfiguredStatusEnum[key]}</Select.Option>
                                })
                            }
                        </Select>
                    </Col>
                    <Col>
                        <Select placeholder='计划类型' style={{ minWidth: 200 }} showSearch filterOption={(input: any, option: any) =>
                            (option!.children as unknown as string).toLowerCase().includes(input.toLowerCase())
                        } allowClear onChange={(value: any) => {
                            getList({ pageNum: 1, pageSize: 20, campaignType: value })
                        }}>
                            {
                                Object.keys(CampaignTypeEnum).map(key => {
                                    // let obj = JSON.parse(PromotedObjectType[key])
                                    console.log(key)
                                    return <Select.Option value={key} key={key}>{CampaignTypeEnum[key]}</Select.Option>
                                })
                            }
                        </Select>
                    </Col>
                </Row>
            </>}
            onChange={(props: any) => {
                let { sortData, pagination } = props
                let { current, pageSize } = pagination
                getList({ pageNum: current, pageSize })
            }}
        />
    </div>
}
export default Campaign